<td ng-class="{
	CDNX_invoicing_order_pending: row.status_order=='PE',
	CDNX_invoicing_order_paid: row.status_order=='PA',
	CDNX_invoicing_order_sent: row.status_order=='SE',
	CDNX_invoicing_order_delivered: row.status_order=='DE',
}">{{ row.customer }}</td>
<td ng-class="{
	CDNX_invoicing_order_pending: row.status_order=='PE',
	CDNX_invoicing_order_paid: row.status_order=='PA',
	CDNX_invoicing_order_sent: row.status_order=='SE',
	CDNX_invoicing_order_delivered: row.status_order=='DE',
}">{{ row.code }}</td>
<td ng-class="{
	CDNX_invoicing_order_pending: row.status_order=='PE',
	CDNX_invoicing_order_paid: row.status_order=='PA',
	CDNX_invoicing_order_sent: row.status_order=='SE',
	CDNX_invoicing_order_delivered: row.status_order=='DE',
}">{{ row.date }}</td>
<td ng-class="{
	CDNX_invoicing_order_pending: row.status_order=='PE',
	CDNX_invoicing_order_paid: row.status_order=='PA',
	CDNX_invoicing_order_sent: row.status_order=='SE',
	CDNX_invoicing_order_delivered: row.status_order=='DE',
}">{{ row.storage }}</td>
<td ng-class="{
	CDNX_invoicing_order_pending: row.status_order=='PE',
	CDNX_invoicing_order_paid: row.status_order=='PA',
	CDNX_invoicing_order_sent: row.status_order=='SE',
	CDNX_invoicing_order_delivered: row.status_order=='DE',
}">{{ row.get_status_order_display }}</td>
<td ng-class="{
	CDNX_invoicing_order_pending: row.status_order=='PE',
	CDNX_invoicing_order_paid: row.status_order=='PA',
	CDNX_invoicing_order_sent: row.status_order=='SE',
	CDNX_invoicing_order_delivered: row.status_order=='DE',
}">{{ row.get_payment_detail_display }}</td>
<td ng-class="{
	CDNX_invoicing_order_pending: row.status_order=='PE',
	CDNX_invoicing_order_paid: row.status_order=='PA',
	CDNX_invoicing_order_sent: row.status_order=='SE',
	CDNX_invoicing_order_delivered: row.status_order=='DE',
}">{{ row.source }}</td>
<td ng-class="{
	CDNX_invoicing_order_pending: row.status_order=='PE',
	CDNX_invoicing_order_paid: row.status_order=='PA',
	CDNX_invoicing_order_sent: row.status_order=='SE',
	CDNX_invoicing_order_delivered: row.status_order=='DE',
}">{{ row.number_tracking }}</td>
<td ng-class="{
	CDNX_invoicing_order_pending: row.status_order=='PE',
	CDNX_invoicing_order_paid: row.status_order=='PA',
	CDNX_invoicing_order_sent: row.status_order=='SE',
	CDNX_invoicing_order_delivered: row.status_order=='DE',
}">{{ row.budget__address_delivery }}</td>
<td ng-class="{
	CDNX_invoicing_order_pending: row.status_order=='PE',
	CDNX_invoicing_order_paid: row.status_order=='PA',
	CDNX_invoicing_order_sent: row.status_order=='SE',
	CDNX_invoicing_order_delivered: row.status_order=='DE',
}">{{ row.budget__address_invoice }}</td>
<td ng-class="{
	CDNX_invoicing_order_pending: row.status_order=='PE',
	CDNX_invoicing_order_paid: row.status_order=='PA',
	CDNX_invoicing_order_sent: row.status_order=='SE',
	CDNX_invoicing_order_delivered: row.status_order=='DE',
}">{{ row.total }}</td>